Welcome to rts_package's documentation!
========================================
.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation.rst
   usage
   
   authors
   changelog
   code_of_conduct

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
